class GlobalSettings {
  static VIPStatus vipStatus = VIPStatus.NO_VIP;
  static bool isUsingIOSBackground = false;
  static bool isUsingWaveProgress = false;
  static bool isUsingChangeLineSubmit = false;
  static bool isUsingSimMode = false;
  static bool isUsingYishi = false;
  static User user;
  static String token;
  static String userAddr;
  static int sortBy;
  static double fontScaleLevel;

  static init() {
    getUsingIOSBackground();
    getVIPStatus();
    getUsingChangeLineSubmit();
    getUsingSimMode();
    getToken();
    getUserAddr();
    getUsingYishi();
    getSortBy();
    getFontScaleLevel();
  }

  static updateFontSize() {
    if (fontScaleLevel > 3.0) {
      fontScaleLevel *= 0.4;
    } else if (fontScaleLevel > 2.0) {
      fontScaleLevel *= 0.5;
    } else if (fontScaleLevel > 1.0) {
      fontScaleLevel *= 0.7;
    }
    print('font scale is: $fontScaleLevel');
    NORMAL_FONT_SIZE = FONT_SIZE_BASE * fontScaleLevel;
    HERO_FONT_SIZE = FONT_SIZE_BASE * 1.1 * fontScaleLevel;
    SMALL_FONT_SIZE = FONT_SIZE_BASE * 0.9 * fontScaleLevel;
    EX_SMALL_FONT_SIZE = FONT_SIZE_BASE * 0.8 * fontScaleLevel;
    NORMAL_TXT_STYLE = NORMAL_TXT_STYLE.copyWith(fontSize: NORMAL_FONT_SIZE);
    NORMAL_BOLD_TXT_STYLE =
        NORMAL_BOLD_TXT_STYLE.copyWith(fontSize: NORMAL_FONT_SIZE);
    SMALL_TXT_STYLE = SMALL_TXT_STYLE.copyWith(fontSize: SMALL_FONT_SIZE);
    SMALL_BOLD_TXT_STYLE =
        SMALL_BOLD_TXT_STYLE.copyWith(fontSize: SMALL_FONT_SIZE);

    print('Now font size setting is: NORMAL_FONT_SIZE: ${NORMAL_FONT_SIZE}, ' +
        'HERO_FONT_SIZE: ${HERO_FONT_SIZE}: SMALL_FONT_SIZE: ${SMALL_FONT_SIZE}');
  }

  static setFontScaleLevel(double l) {
    SharedPreferenceUtil.saveDouble(
        SharedPreferenceUtil.KEY_FONT_SCALE_LEVEL, l);
    fontScaleLevel = l;
  }

  static getFontScaleLevel() async {
    fontScaleLevel = await SharedPreferenceUtil.getDouble(
        SharedPreferenceUtil.KEY_FONT_SCALE_LEVEL);
    double _dS = 1.0;
    if (!isOnMobile()) {
      _dS = 1.6;
      // not on mobile, default Scale bigger
    }
    fontScaleLevel = fontScaleLevel == null ? _dS : fontScaleLevel;
  }

  static setUserAddr(String ua) {
    SharedPreferenceUtil.save(SharedPreferenceUtil.KEY_ACCOUNT_ADDR, ua);
    userAddr = userAddr;
  }

  static getUserAddr() async {
    userAddr =
        await SharedPreferenceUtil.get(SharedPreferenceUtil.KEY_ACCOUNT_ADDR);
  }

  static getSortBy() async {
    sortBy = await SharedPreferenceUtil.getInt(
        SharedPreferenceUtil.KEY_SETTING_SORT_BY);
    sortBy = sortBy ?? SORT_BY.BY_DUE_DATE.index;
  }

  static setSortBy(int v) {
    SharedPreferenceUtil.saveInt(SharedPreferenceUtil.KEY_SETTING_SORT_BY, v);
  }

  static setUser(User u) {
    user = u;
  }

  static setVIPStatus(int s) {
    vipStatus = VIPStatus.values[s];
  }

  static getVIPStatus() async {
    var _vipPlan =
        await SharedPreferenceUtil.getInt(SharedPreferenceUtil.KEY_VIP_PLAN);
    var _vipStartTime = await SharedPreferenceUtil.getInt(
        SharedPreferenceUtil.KEY_VIP_START_TIME);
    if (_vipPlan == null) {
      vipStatus = VIPStatus.NO_VIP;
    } else if (IsVipValid(
        _vipPlan, DateTime.fromMillisecondsSinceEpoch(_vipStartTime))) {
      vipStatus = VIPStatus.VIP_OK;
    } else {
      vipStatus = VIPStatus.VIP_EXPIRED;
    }
  }

  static setUsingIOSBackground(bool v) {
    isUsingIOSBackground = v;
    SharedPreferenceUtil.saveBool(SharedPreferenceUtil.KEY_SETTING_USE_IOS, v);
  }

  static setUsingYishi(bool v) {
    isUsingYishi = v;
    SharedPreferenceUtil.saveBool(SharedPreferenceUtil.KEY_SETTING_YISHIGAN, v);
  }

  static setToken(String v) {
    token = v;
    SharedPreferenceUtil.save(SharedPreferenceUtil.KEY_TOKEN, v);
  }

  static getToken() async {
    token = await SharedPreferenceUtil.get(SharedPreferenceUtil.KEY_TOKEN);
  }

  static setUsingChangeLineSubmit(bool v) {
    isUsingChangeLineSubmit = v;
    SharedPreferenceUtil.saveBool(
        SharedPreferenceUtil.KEY_SETTING_CHANGE_LINE_COMPLETE, v);
  }

  static getUsingChangeLineSubmit() async {
    isUsingChangeLineSubmit = await SharedPreferenceUtil.getBool(
        SharedPreferenceUtil.KEY_SETTING_CHANGE_LINE_COMPLETE);
    return isUsingChangeLineSubmit;
  }

  static getUsingYishi() async {
    isUsingYishi = await SharedPreferenceUtil.getBool(
        SharedPreferenceUtil.KEY_SETTING_YISHIGAN);
    return isUsingYishi;
  }

  static getUsingSimMode() async {
    isUsingSimMode = await SharedPreferenceUtil.getBool(
        SharedPreferenceUtil.KEY_SETTING_SIM_MODE);
    return isUsingSimMode;
  }

  static getUsingIOSBackground() async {
    isUsingIOSBackground = await SharedPreferenceUtil.getBool(
        SharedPreferenceUtil.KEY_SETTING_USE_IOS);
    return isUsingIOSBackground;
  }

  static setUsingWaveProgress(bool v) {
    isUsingWaveProgress = v;
    SharedPreferenceUtil.saveBool(
        SharedPreferenceUtil.KEY_SETTING_USE_WAVE_PG, v);
  }

  static setUsingSimMode(bool v) {
    isUsingSimMode = v;
    SharedPreferenceUtil.saveBool(SharedPreferenceUtil.KEY_SETTING_SIM_MODE, v);
  }

  static getUsingWaveProgress() async {
    isUsingWaveProgress = await SharedPreferenceUtil.getBool(
        SharedPreferenceUtil.KEY_SETTING_USE_WAVE_PG);
    return isUsingWaveProgress;
  }
}
