import 'dart:math';

import 'package:flutter/material.dart';
import 'package:flutter_local_notifications/flutter_local_notifications.dart';
import 'package:flutter_svg/svg.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'dart:io' show Platform;
import 'package:package_info/package_info.dart';

// priority icons
List<Widget> priorityIcons = [
  Icon(
    FlutterIcons.favorite_mdi,
    color: Colors.red,
  ),
  Icon(
    FlutterIcons.star_and_crescent_faw5s,
    color: Colors.orange,
  ),
  Icon(
    FlutterIcons.upcircle_ant,
    color: Colors.blue,
  ),
  Icon(
    FlutterIcons.coffee_to_go_mco,
    color: Colors.green,
  ),
];

buildBackButton(BuildContext context, color) {
  return Row(
    crossAxisAlignment: CrossAxisAlignment.center,
    mainAxisAlignment: MainAxisAlignment.end,
    children: [
      // IconButton(
      //   padding: EdgeInsets.all(0),
      //   icon: Icon(FlutterIcons.ios_arrow_back_ion, color: color, size: 30,),
      //   onPressed: () => Navigator.of(context).pop(),
      // )
      IconButton(
        padding: EdgeInsets.all(0),
        icon: Icon(
          FlutterIcons.chevron_left_fea,
          color: color,
          size: 28,
        ),
        onPressed: () => Navigator.of(context).pop(),
      ),
    ],
  );
}

buildAppBarTitle(
  String title,
  color,
  BuildContext context,
) {
  return Align(
    alignment: Alignment.centerLeft,
    child: Text(
      title,
      style: NORMAL_BOLD_TXT_STYLE.copyWith(color: color),
    ),
  );
}

buildBackButtonCross(BuildContext context, color) {
  return IconButton(
    icon: Icon(
      FlutterIcons.ios_close_circle_ion,
      color: Colors.grey,
      size: 25,
    ),
    onPressed: () => Navigator.of(context).pop(),
  );
}

showToast(BuildContext context, String msg,
    {Color c = COLOR_ACCENT,
    Widget icon = const Icon(
      Icons.check,
      color: Colors.white,
    )}) {
  FlutterToast flutterToast = FlutterToast(context);
  Widget toast = Container(
    padding: const EdgeInsets.symmetric(horizontal: 24.0, vertical: 12.0),
    decoration: BoxDecoration(
      borderRadius: BorderRadius.circular(25.0),
      color: COLOR_PRIMARY,
    ),
    child: Row(
      mainAxisSize: MainAxisSize.min,
      children: [
        icon,
        SizedBox(
          width: 12.0,
        ),
        Flexible(
          child: Text(
            msg,
            style: TextStyle(color: Colors.white),
          ),
        )
      ],
    ),
  );

  flutterToast.showToast(
    child: toast,
    gravity: ToastGravity.BOTTOM,
    toastDuration: Duration(seconds: 2),
  );
}

showSnackbar(GlobalKey<ScaffoldState> scaffoldState, String message,
    {MaterialColor materialColor}) {
  if (message.isEmpty) return;
  // Find the Scaffold in the Widget tree and use it to show a SnackBar
  scaffoldState.currentState.showSnackBar(
      SnackBar(content: Text(message), backgroundColor: materialColor));
}

// Move to app widgets
Widget buildListTile(Widget leading, Widget title, Widget subtitle,
    Widget tailing, bool roundTop, bool roundBottom, onTap,
    {onTapDown,
    padding: const EdgeInsets.symmetric(horizontal: 6, vertical: 6)}) {
  BorderRadius radius = BorderRadius.zero;
  double _radius = 15;
  if (roundTop) {
    radius = BorderRadius.only(
        topLeft: Radius.circular(_radius), topRight: Radius.circular(_radius));
  }
  if (roundBottom) {
    radius = BorderRadius.only(
        bottomLeft: Radius.circular(_radius),
        bottomRight: Radius.circular(_radius));
  }

  if (roundBottom && roundTop) {
    radius = BorderRadius.only(
        topLeft: Radius.circular(_radius),
        topRight: Radius.circular(_radius),
        bottomLeft: Radius.circular(_radius),
        bottomRight: Radius.circular(_radius));
  }
  return Card(
    elevation: 9,
    shadowColor: Colors.grey.withAlpha(20),
    margin: EdgeInsets.all(0),
    shape: RoundedRectangleBorder(
      borderRadius: radius,
    ),
    child: InkWell(
        borderRadius: radius,
        onTap: onTap,
        onTapDown: onTapDown,
        child: Padding(
          padding: padding,
          child: Row(
              mainAxisSize: MainAxisSize.min,
              mainAxisAlignment: MainAxisAlignment.start,
              children: [
                SizedBox(
                  width: 12,
                ),
                leading,
                SizedBox(
                  width: 18,
                ),
                Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  mainAxisSize: MainAxisSize.min,
                  children: <Widget>[title, SizedBox(height: 2), subtitle],
                ),
                Expanded(
                  child: Row(
                    mainAxisAlignment: MainAxisAlignment.end,
                    children: <Widget>[tailing, SizedBox(width: 8)],
                  ),
                )
              ]),
        )),
  );
}

Widget buildLDoubleListTile(
    Widget left, Widget right, bool roundTop, bool roundBottom, onTap1, onTap2,
    {onTapDown1, onTapDown2}) {
  BorderRadius radius = BorderRadius.zero;
  double _radius = 15;
  if (roundTop) {
    radius = BorderRadius.only(
        topLeft: Radius.circular(_radius), topRight: Radius.circular(_radius));
  }
  if (roundBottom) {
    radius = BorderRadius.only(
        bottomLeft: Radius.circular(_radius),
        bottomRight: Radius.circular(_radius));
  }

  if (roundBottom && roundTop) {
    radius = BorderRadius.only(
        topLeft: Radius.circular(_radius),
        topRight: Radius.circular(_radius),
        bottomLeft: Radius.circular(_radius),
        bottomRight: Radius.circular(_radius));
  }
  return Card(
    elevation: 9,
    shadowColor: Colors.grey.withAlpha(20),
    margin: EdgeInsets.all(0),
    shape: RoundedRectangleBorder(
      borderRadius: radius,
    ),
    child: Padding(
      padding: EdgeInsets.symmetric(horizontal: 6, vertical: 6),
      child: Row(mainAxisAlignment: MainAxisAlignment.spaceEvenly, children: [
        Expanded(
          child: InkWell(
            borderRadius: radius,
            onTap: onTap1,
            onTapDown: onTapDown1,
            child: left,
          ),
        ),
        Expanded(
          child: InkWell(
            borderRadius: radius,
            onTap: onTap2,
            onTapDown: onTapDown2,
            child: right,
          ),
        )
      ]),
    ),
  );
}

Widget buildListTileNoShadow(Widget leading, Widget title, Widget subtitle,
    Widget tailing, bool roundTop, bool roundBottom, onTap,
    {onTapDown}) {
  BorderRadius radius = BorderRadius.zero;
  double _radius = 5;
  if (roundTop) {
    radius = BorderRadius.only(
        topLeft: Radius.circular(_radius), topRight: Radius.circular(_radius));
  }
  if (roundBottom) {
    radius = BorderRadius.only(
        bottomLeft: Radius.circular(_radius),
        bottomRight: Radius.circular(_radius));
  }

  if (roundBottom && roundTop) {
    radius = BorderRadius.only(
        topLeft: Radius.circular(_radius),
        topRight: Radius.circular(_radius),
        bottomLeft: Radius.circular(_radius),
        bottomRight: Radius.circular(_radius));
  }
  return Card(
      elevation: 0,
      // shadowColor: Colors.grey.withAlpha(30),
      margin: EdgeInsets.all(0),
      // color: Colors.teal,
      shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(0)),
      child: Padding(
        padding: EdgeInsets.symmetric(horizontal: 16, vertical: 6),
        child: InkWell(
            borderRadius: radius,
            onTap: onTap,
            onTapDown: onTapDown,
            child: Padding(
              padding: EdgeInsets.symmetric(horizontal: 6, vertical: 6),
              child: Row(mainAxisAlignment: MainAxisAlignment.start, children: [
                SizedBox(
                  width: 12,
                ),
                leading,
                SizedBox(
                  width: 18,
                ),
                Expanded(
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: <Widget>[
                      title,
                      SizedBox(height: 2),
                      Wrap(
                        children: [subtitle],
                      )
                    ],
                  ),
                ),
                Row(
                  mainAxisAlignment: MainAxisAlignment.end,
                  children: <Widget>[tailing, SizedBox(width: 8)],
                ),
              ]),
            )),
      ));
}

bool isAppInDarkMode(BuildContext context) {
  Brightness brightness = MediaQuery.platformBrightnessOf(context);
  return brightness == Brightness.dark;
}

launchURL(String url) async {
  if (url.isEmpty) return;
  if (await canLaunch(url)) {
    await launch(url);
  } else {
    throw 'Could not launch $url';
  }
}

bool isTaskOverdue(Tasks tasks) {
  var n = DateTime.now();
  if (tasks.dueDate < DateTime(n.year, n.month, n.day).millisecondsSinceEpoch) {
    return true;
  } else {
    return false;
  }
}

int getTaskTimeToGo(Tasks t) {
  DateTime d = DateTime.now();
  // DateTime dd = DateTime.fromMillisecondsSinceEpoch(t.dueDate);
  int a = t.dueDate - d.millisecondsSinceEpoch;
  // var a = dd.day - d.day;
  var dd = a ~/ Duration.millisecondsPerDay;
  return dd;
}

String getRepeatedOptionText(RepeatedOption repeatedOption) {
  if (repeatedOption != null && repeatedOption.repeatedPer > 0) {
    var _t = '每';
    switch (repeatedOption.repeatedUnit) {
      case RepeatUnit.DAY:
        _t += '${repeatedOption.repeatedPer}天';
        break;
      case RepeatUnit.MONTH:
        _t += '${repeatedOption.repeatedPer}月';
        break;
      case RepeatUnit.YEAR:
        _t += '${repeatedOption.repeatedPer}年';
        break;
      case RepeatUnit.WEEK:
        _t += '周${repeatedOption.repeatedNumbers}';
        break;
      default:
        _t += '${repeatedOption.repeatedPer}天';
        break;
    }
    return _t;
  } else {
    return '不重复';
  }
}

class MessageInCenterWidget extends StatelessWidget {
  final String _message;

  MessageInCenterWidget(this._message);
  @override
  Widget build(BuildContext context) {
    return Center(
      child: Column(mainAxisAlignment: MainAxisAlignment.center, children: [
        // Icon(
        //   FlutterIcons.beach_mco,
        //   size: 77,
        //   color: Colors.grey.withAlpha(60),
        // ),
        SvgPicture.asset(
          gIllus[Random().nextInt(gIllus.length)],
          height: 200,
        ),
        SizedBox(
          height: 20,
        ),
        Text(_message,
            style: TextStyle(
                fontSize: FONT_MEDIUM, color: Colors.grey.withAlpha(60)))
      ]),
    );
  }
}

bool isOnMobile() {
  return Platform.isIOS || Platform.isAndroid;
}

bool isOniPhone() {
  return Platform.isIOS;
}

bool isDarkModeOn(BuildContext context) {
  var brightness = MediaQuery.of(context).platformBrightness;
  bool darkModeOn = brightness == Brightness.dark;
  return darkModeOn;
}

Future<DisplayMode> getCurrentMode() async {
  return await FlutterDisplayMode.current;
}

void initDefaultRefreshRate() async {
  final DisplayMode m = await getCurrentMode();
  await FlutterDisplayMode.setMode(m);
  print('已经设置为默认刷新率: $m');
}


Future<String> getAppName() async {
  PackageInfo packageInfo = await PackageInfo.fromPlatform();
  return packageInfo.appName;
}

Future<String> getAppVersion() async {
  PackageInfo packageInfo = await PackageInfo.fromPlatform();
  return packageInfo.version;
}

Future<String> getBuildNumber() async {
  PackageInfo packageInfo = await PackageInfo.fromPlatform();
  return packageInfo.buildNumber;
}

