import 'dart:convert';
import 'dart:io';
import 'dart:typed_data';

import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import '../apis/api_constants.dart';
import 'package:meta/meta.dart';

class User {
  User(
      {@required this.userAddr,
      @required this.userNickName,
      @required this.userCity,
      @required this.userSign,
      @required this.userBirth,
      @required this.userAcc,
      @required this.userAvatarUrl,
      this.userAvatar,
      this.userGender,
      this.userType,
      this.enableAnonymous,
      this.anonymousNickName,
      this.anonymousGender,
      this.anonymousSign,
      this.anonymousCity,
      this.userAvatarUrlShort,
      this.anonymousAvatarID,
      this.userAvatarImage,
      this.userLevel,
      this.loginType,
      this.accType,
      this.vipPlan,
      this.vipStartTime,
      this.userID,
      this.userRegisterTime,
      this.selectedImgAvatar});

  String userAddr;
  String userAcc;
  String userNickName;
  String userCity;
  String userSign;
  String userBirth;
  String userAvatarUrl;
  String userAvatarUrlShort;
  String userAvatar;

  bool enableAnonymous;
  String anonymousNickName;
  String anonymousGender;
  String anonymousCity;
  String anonymousSign;
  String anonymousAvatarID;

  int userLevel;
  int loginType;
  int accType;

  ImageProvider userAvatarImage;

  // if no vipStartTime means no vip
  int vipPlan;
  DateTime vipStartTime;

  int userType;
  //  same as userTYpe
  String userGender;

  DateTime userRegisterTime;
  int userID;

  File selectedImgAvatar;

  static User fromMap(Map map) {
    // print('---- map: {$map}');
    String uG = map['user_gender'];
    var userAvatar = map['user_avatar'];
    var userAvatarUrl = map['user_avatar_url'];
    if (userAvatar == null) {
      userAvatar = '';
    }

    int userGender;
    if (uG == '' || uG == null || uG == "null") {
      userGender = 0;
    } else {
      userGender = int.parse(map['user_gender']);
    }
    String userGenderStr = '';
    switch (userGender) {
      case 0:
        userGenderStr = '男';
        break;
      case 1:
        userGenderStr = '女';
        break;
      case 2:
        userGenderStr = '机器人';
        break;
    }
    var userBirth;
    if (map['user_birth'] == '' || map['user_birth'] == null) {
      userBirth = '1998';
    } else {
      userBirth = map['user_birth'];
    }

    ImageProvider userAvatarImage;
    if (userAvatarUrl != null && userAvatarUrl != '') {
      // print('userAvatarUrl: ${userAvatarUrl}');
      // userAvatarImage =
      //     CachedNetworkImageProvider(API.BASE_URL + userAvatarUrl);
      userAvatarImage =
          NetworkImage(API.BASE_URL + userAvatarUrl);
    } else if (userAvatar != null && userAvatar != '') {
      Uint8List bytes = base64.decode(userAvatar);
      userAvatarImage = MemoryImage(bytes);
    } else {
      userAvatarImage = AssetImage('assets/images/user.jpg');
    }

    DateTime vipStartTime;
    int vipPlan;
    // prepare for vip info
    if (map['vips'] != null) {
      // user have vip info
      for (var vipInfo in map['vips']) {
        if (vipInfo['vip_app'] == 'daybreak') {
          //
          print('----------------- ${map['vip_start_time']}');
          vipStartTime = DateTime.parse(vipInfo['vip_start_time']).toLocal();
          vipPlan = vipInfo['vip_plan'];
        }
      }
    }

    DateTime _registerTime;
    if (map['user_register_time'] != null) {
      DateTime.parse(map['user_register_time']);
    } else {
      _registerTime = DateTime.now();
    }

    return new User(
      userAvatarImage: userAvatarImage,
      userAddr: map['user_addr'],
      userAvatar: userAvatar,
      userNickName: map['user_nick_name'],
      userAcc: map['user_acc'],
      userCity: map['user_city'],
      userSign: map['user_sign'],
      enableAnonymous: map['enable_anonymous'],
      userBirth: userBirth,
      userAvatarUrl: API.BASE_URL + userAvatarUrl,
      userAvatarUrlShort: userAvatarUrl,
      anonymousNickName: map['anonymous_nick_name'],
      anonymousGender: map['anonymous_gender'],
      anonymousSign: map['anonymous_sign'],
      anonymousCity: map['anonymous_city'],
      anonymousAvatarID: map['anonymous_avatar_id'],
      userGender: userGenderStr,
      userType: 0,
      userLevel: map['user_level'],
      loginType: map['login_type'],
      accType: map['account_type'],
      vipPlan: vipPlan,
      vipStartTime: vipStartTime,
      userRegisterTime: _registerTime,
      userID: map['user_id'],
    );
  }
}
